"""Provide functionality for downloading GOES and GridSat datasets."""

__package_id__ = "GOES-DL"
__package_name__ = (
    f"{__package_id__} — GOES Satellite Imagery Dataset Downloader"
)
__version__ = "v0.1-rc5"
